#[non_exhaustive]pub struct ColorFieldRenderState {
pub is_disabled: bool,
pub is_invalid: bool,
pub is_read_only: bool,
pub is_required: bool,
pub is_focused: bool,
pub is_focus_within: bool,
pub is_focus_visible: bool,
}Expand description
The complete state passed to ColorField::content.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.is_disabled: boolThe field cannot receive focus or input.
is_invalid: boolControlled, server, or custom validation currently fails.
is_read_only: boolThe value can be selected but not changed.
is_required: boolThe field must contain a value before native form submission.
is_focused: boolThe input itself owns keyboard focus.
is_focus_within: boolThe input or another composed child owns keyboard focus.
is_focus_visible: boolFocus was reached through keyboard navigation.