#[non_exhaustive]pub struct DatePickerRenderState {
pub is_disabled: bool,
pub is_invalid: bool,
pub is_read_only: bool,
pub is_required: bool,
pub is_focus_within: bool,
pub is_focus_visible: bool,
pub is_open: bool,
}Expand description
The complete state passed to DatePicker::content.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.is_disabled: boolThe picker cannot receive focus, edit its field, or open its calendar.
is_invalid: boolControlled or constraint validation currently fails.
is_read_only: boolThe field can be focused but not edited or opened.
is_required: boolThe picker must contain a date before native form submission.
is_focus_within: boolA composed child currently owns focus.
is_focus_visible: boolFocus within the picker was reached through keyboard navigation.
is_open: boolThe calendar popover is currently open.