#[non_exhaustive]pub struct DateRangePickerRenderState {
pub is_disabled: bool,
pub is_invalid: bool,
pub is_read_only: bool,
pub is_required: bool,
pub is_focus_within: bool,
pub is_focus_visible: bool,
pub is_open: bool,
}Expand description
State passed to DateRangePicker’s v3 children render function.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.is_disabled: boolThe whole picker is unavailable.
is_invalid: boolEither range end currently fails validation.
is_read_only: boolThe range can be focused but not edited.
is_required: boolBoth range ends must contain dates before native submission.
is_focus_within: boolA composed child currently owns focus.
is_focus_visible: boolFocus within the picker was reached through keyboard navigation.
is_open: boolThe range calendar popover is currently open.