pub fn interactive_cursor(cx: &App) -> CursorStyleExpand description
The theme’s interactive cursor, for a site that must capture it by value.
pub fn interactive_cursor(cx: &App) -> CursorStyleThe theme’s interactive cursor, for a site that must capture it by value.