UiString

Enum UiString 

#[non_exhaustive]
pub enum UiString {
Show 31 variants SelectPlaceholder, NoResults, Close, Loading, Previous, Next, Remove, Breadcrumbs, Search, Increase, Decrease, Year, Month, Day, Hour, Minute, Second, DayPeriod, Calendar, DateSelected, Hue, Saturation, Lightness, Brightness, Red, Green, Blue, Alpha, ClearSelection, Pagination, LoadingMore,
}
A component chrome string. See the module docs.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


SelectPlaceholder

Select / Autocomplete placeholder (selectPlaceholder, RAC).



NoResults

Autocomplete’s empty-collection message (HeroUI; HeroGPUI translations).



Close

CloseButton’s accessible name (close, React Aria toast).



Loading

Spinner’s accessible name (HeroUI; HeroGPUI translations).



Previous

Calendar previous-page button (previous, React Aria calendar).



Next

Calendar next-page button (next, React Aria calendar).



Remove

Tag remove button (removeButtonLabel, React Aria tag).



Breadcrumbs

Breadcrumbs list name (breadcrumbs, React Aria breadcrumbs).



Search

SearchField placeholder (HeroUI; HeroGPUI translations).



Increase

NumberField / TimeField increment stepper, a {fieldLabel} template (increase, React Aria numberfield).



Decrease

NumberField / TimeField decrement stepper, a {fieldLabel} template (decrease, React Aria numberfield).



Year

The year segment’s name (year, React Aria datepicker).



Month

The month segment’s name (month, React Aria datepicker).



Day

The day segment’s name (day, React Aria datepicker).



Hour

The hour segment’s name (hour, React Aria datepicker).



Minute

The minute segment’s name (minute, React Aria datepicker).



Second

The second segment’s name (second, React Aria datepicker).



DayPeriod

The AM/PM segment’s name (dayPeriod, React Aria datepicker).



Calendar

The DatePicker calendar button (calendar, React Aria datepicker).



DateSelected

A selected calendar day, a {date} template (dateSelected, React Aria calendar).



Hue

The hue channel (hue, React Stately color).



Saturation

The saturation channel (saturation, React Stately color).



Lightness

The HSL lightness channel (lightness, React Stately color).



Brightness

The HSB brightness channel (brightness, React Stately color).



Red

The red channel (red, React Stately color).



Green

The green channel (green, React Stately color).



Blue

The blue channel (blue, React Stately color).



Alpha

The alpha channel (alpha, React Stately color).



ClearSelection

Autocomplete’s clear button (HeroUI; HeroGPUI translations).



Pagination

Pagination’s navigation name (HeroUI; HeroGPUI translations).



LoadingMore

Table’s load-more row text while is_pending (HeroUI; HeroGPUI translations: UiString::Loading with an ellipsis).

Implementations

Source

impl UiString

pub const COUNT: usize = 31

The number of keys.

pub const ALL: [UiString; 31]

Every key, in declaration order.