pub struct TimeState {
pub value: Option<Time>,
pub focused: TimeSegment,
/* private fields */
}Expand description
State entity for TimeField.
Fields
value: Option<Time>The complete value exposed to callbacks, validation and forms.
focused: TimeSegmentThe segment that currently has focus.
Implementations
Sourceimpl TimeState
impl TimeState
Sourcepub fn with_value(cx: &mut App, value: Time) -> Self
pub fn with_value(cx: &mut App, value: Time) -> Self
Creates a state holding value, focused on the hour segment.
Sourcepub fn bump_focused_from(&mut self, delta: i32, seed: Time)
pub fn bump_focused_from(&mut self, delta: i32, seed: Time)
Adjusts the focused segment, seeding an empty field from seed.
Sourcepub fn bump_focused(&mut self, delta: i32)
pub fn bump_focused(&mut self, delta: i32)
bump_focused_from seeded at midnight.